@@ -16,6 +16,7 @@
 #' 
 #' @param location Directory where the files are located.
 #' @param reference Name of the reference file.
+#' @param run_dsa Run DSA?
 #' @param run_psa Run PSA?.
 #' @param run_demo Run demgraphic analysis?
 #' @param save Should the outputs be saved?
@@ -29,11 +30,13 @@
 #'   
 #' @export
 run_model_tabular <- function(location, reference = "REFERENCE.csv",
+                              run_dsa = TRUE, 
                               run_psa = TRUE, run_demo = TRUE,
                               save = FALSE, overwrite = FALSE) {
   
   inputs <- gather_model_info(location, reference)
   outputs <- eval_models_from_tabular(inputs,
+                                      run_dsa = run_dsa,
                                       run_psa = run_psa,
                                       run_demo = run_demo)
   
@@ -172,6 +175,7 @@ gather_model_info <- function(base_dir, ref_file) {
 #' 
 #' @param inputs Result from 
 #'   [gather_model_info()].
+#' @param run_dsa Run DSA?
 #' @param run_psa Run PSA?
 #' @param run_demo Run demographic analysis?
 #'   
@@ -187,6 +191,7 @@ gather_model_info <- function(base_dir, ref_file) {
 #'   
 #' @keywords internal
 eval_models_from_tabular <- function(inputs,
+                                     run_dsa = TRUE,
                                      run_psa = TRUE,
                                      run_demo = TRUE) {
   
@@ -225,7 +230,7 @@ eval_models_from_tabular <- function(inputs,
   )
   
   model_dsa <- NULL
-  if (! is.null(inputs$param_info$dsa)) {
+  if (run_dsa & ! is.null(inputs$param_info$dsa)) {
     if (options()$heemod.verbose) message("** Running DSA...")
     model_dsa <- run_dsa(
       model_runs,
@@ -274,8 +279,11 @@ create_model_list_from_tabular <- function(ref, df_env = globalenv()) {
   if(! inherits(ref, "data.frame")) stop("'ref' must be a data frame.")
   
   if (options()$heemod.verbose) message("*** Reading states...")
+  state_file_info <- 
+    read_file(ref$full_file[ref$data == "state"])
+  
   state_info <- parse_multi_spec(
-    read_file(ref$full_file[ref$data == "state"]),
+    state_file_info,
     group_vars = ".state"
   )
   state_names <- state_info[[1]]$.state
@@ -290,7 +298,8 @@ create_model_list_from_tabular <- function(ref, df_env = globalenv()) {
     tm_info <- parse_multi_spec(
       tm_info,
       group_vars = c("from", "to"))
-    tab_undefined <- do.call("rbind", tm_info) %>% 
+    tab_undefined <- 
+      dplyr::bind_rows(tm_info) %>%
       dplyr::filter_(~ is.na(prob))
     
     if (nrow(tab_undefined) > 0) {
@@ -303,47 +312,56 @@ create_model_list_from_tabular <- function(ref, df_env = globalenv()) {
   }
   
   
-  # if (trans_type == "part_surv"){
-  #   fit_tib <- survival_fits_from_ref_struc(
-  #     ref, df_env,
-  #     save_fits = FALSE,
-  #     just_load = TRUE)[[1]]
-  #   
-  #   assign("fit_tib", fit_tib, df_env)
-  #   use_fits_file <- ref[ref$data == "use_fits", "full_file"]
-  #   use_fits <- read_file(use_fits_file)
-  #   tm_info <- construct_part_surv_tib(use_fits, fit_tib, env = df_env,
-  #                                      state_names = state_names)
-  #   one_way <- setdiff(names(state_info), unique(tm_info$.strategy))
-  #   other_way <- setdiff(unique(tm_info$.strategy), names(state_info))
-  # }
-  
-  if (length(pb <- union(one_way, other_way))) {
-    stop(sprintf(
-      "Mismatching model names between TM file and state file: %s.",
-      paste(pb, collapse = ", ")
-    ))
+  if(trans_type == "part_surv"){
+    use_fits_file <- ref[ref$data == "use_fits", "full_file"]
+    use_fits <- read_file(use_fits_file)
+    tm_info <- construct_part_surv_tib(use_fits, ref, env = df_env,
+                                    state_names = state_names)
+    one_way <- setdiff(names(state_info), unique(tm_info$.strategy))
+    other_way <- setdiff(unique(tm_info$.strategy), names(state_info))
+  }
+
+
+  one_way <- setdiff(names(state_info), names(tm_info))
+  other_way <- setdiff(names(tm_info), names(state_info))
+  if (length(c(one_way, other_way))){
+    err_string <- "Mismatching model names between transition (TM) file and state file.\n"
+    if(length(one_way))
+      err_string <-
+        paste(err_string,
+              "In state file but not TM file:", 
+              paste(one_way, collapse = ", "),
+              "\n")
+    if(length(other_way))
+      err_string <-
+        paste(err_string,
+              "In TM but not state file:", 
+              paste(other_way, collapse = ", "),
+              "\n")
+    stop(err_string)
   }
   
-  if (trans_type == "part_surv") {
-    tm_info <- dplyr::filter_(tm_info, ~.strategy %in% names(state_info))
-  } else {
+  
+  if(trans_type == "part_surv")
+    tm_info <- 
+      dplyr::filter_(tm_info, ~ .strategy %in% names(state_info))
+  else
     tm_info <- tm_info[names(state_info)]
-  }
+
+
   if (options()$heemod.verbose) message("*** Defining models...")
   models <- lapply(
     seq_along(state_info),
     function(i) {
-      if (inherits(tm_info, "tbl_df")) {
+      if(inherits(tm_info, "tbl_df"))
         this_tm <- dplyr::filter_(
           tm_info,
           ~ .strategy == names(state_info)[i])$part_surv[[1]]
-      } else {
+      else
         this_tm <- tm_info[[i]]
-        create_model_from_tabular(state_info[[i]], 
-                                  this_tm,
-                                  df_env = df_env)
-      }
+      create_model_from_tabular(state_info[[i]], 
+                                this_tm,
+                                df_env = df_env)
     })  
   
   names(models) <- names(state_info)
@@ -373,7 +391,8 @@ create_model_list_from_tabular <- function(ref, df_env = globalenv()) {
 #' 
 #' The input data frame is expected to contain state 
 #' information for all the models you will use in an 
-#' analysis.
+#' analysis. For more information see the vignette: 
+#' `vignette("file-input", package = "heemod")`.
 #' 
 #' @param state_info Result for one model of 
 #'   [parse_multi_spec()].
@@ -389,7 +408,7 @@ create_states_from_tabular <- function(state_info,
     stop("'state_info' must be a data frame.")
   }
   if(!(".state" %in% names(state_info))) {
-    stop("'.state' should be a column name.")
+    stop("'.state' should be a column name of the state file.")
   }
   if (any(duplicated(state_info$.state))) {
     stop(sprintf(
@@ -399,11 +418,32 @@ create_states_from_tabular <- function(state_info,
     ))
   }
   
+  
+  
   state_names <- state_info$.state
   values <- setdiff(names(state_info), c(".model", ".state"))
   discounts <- values[grep("^\\.discount", values)]
   values <- setdiff(values, discounts)
   discounts_clean <- gsub("^\\.discount\\.(.+)", "\\1", discounts)
+
+  num_missing_per_column <- colSums(sapply(state_info, is.na))
+  missing_col_names <- names(num_missing_per_column)[num_missing_per_column > 0]
+  ## missing names are allowed for discount columns
+  missing_col_names <- setdiff(missing_col_names, discounts)
+  if(length(missing_col_names)){
+    stop("value",
+         plur(length(missing_col_names)),
+         " ",
+         paste(missing_col_names, collapse = ", "),
+         " for strategy '",
+         unique(state_info$.model),
+         "'",
+         ifelse(length(missing_col_names) == 1, " has ", " have "),
+         "missing values in the state file.\n",
+         "Please make sure all values are defined for all states ",
+         "(even when the value is 0)."
+    )
+  }
   
   if (! all(discounts_clean %in% values)) {
     stop(sprintf(
@@ -586,7 +626,7 @@ create_parameters_from_tabular <- function(param_defs,
     }
     
     if (all(is.na(param_defs$low))) {
-      stop("Non non-missing values in columns 'low' and 'high'.")
+      stop("No non-missing values in columns 'low' and 'high'.")
     }
     
     param_sens <- param_defs$parameter[! is.na(param_defs$low)]
@@ -684,7 +724,9 @@ create_options_from_tabular <- function(opt) {
   }
   
   if (any(duplicated(opt$option))) {
-    stop("Some option names are duplicated.")
+    stop("Some option names are duplicated: ",
+         paste(unique(opt$option[duplicated(opt$option)]),
+               collapse = ", "))
   }
   
   res <- list()
@@ -694,6 +736,12 @@ create_options_from_tabular <- function(opt) {
   names(res) <- opt$option
   
   if (! is.null(res$init)) {
+    if(substr(res$init, 1, 2) == "c(" & 
+       substr(res$init, nchar(res$init), nchar(res$init)) == ")"){
+      res$init <- substr(res$init, 3, nchar(res$init))
+      res$init <- substr(res$init, 1, nchar(res$init) - 1)
+      warning("initial values enclosed in c(); removing")
+    }
     res$init <- as_numeric_safe(
       strsplit(res$init, ",")[[1]]
     )
@@ -771,7 +819,10 @@ create_model_from_tabular <- function(state_info,
     TM <- tm_info
   }
   
-  define_strategy_(transition = TM, states = states)
+  define_strategy_(transition = TM, states = states,
+                   starting_values = check_starting_values(
+                     define_starting_values(),
+                     get_state_value_names(states)))
 }
 
 #' Load Data From a Folder Into an Environment
@@ -817,6 +868,27 @@ create_df_from_tabular <- function(df_dir, df_envir) {
   ## do the assignments
   for(i in seq(along = all_files)){
     this_val <- read_file(all_files[i])
+    
+    ## check for accidental commas in numbers
+    comma_cols <- 
+      which(sapply(sapply(this_val, function(x){grep(",", x)}),
+                   any)
+      )
+
+    for(this_comma_col in comma_cols){
+      try_numeric <- try(as.numeric(gsub(",", "", this_val[, this_comma_col])), 
+                         silent = TRUE)
+      if(!inherits(try_numeric, "try-error")){
+        this_val[, this_comma_col] <- try_numeric
+        message(paste("converting column",
+                      names(this_val)[this_comma_col],
+                      "from file",
+                      basename(all_files[i]),
+                      "to numeric despite it having commas"
+                      )
+                )
+    }
+    }
     assign(obj_names[i], this_val, envir = df_envir)
   }
   df_envir
@@ -903,8 +975,8 @@ parse_multi_spec <- function(multi_spec,
     dplyr::group_by_(.dots = group_vars) %>%
     dplyr::filter_(~ n() > 1)
   
-  multi_spec <- rbind(just_once, as.data.frame(more_than_once))
-  
+  multi_spec <- 
+    dplyr::bind_rows(just_once, as.data.frame(more_than_once))
   rownames(multi_spec) <- NULL
   list_spec <- split(multi_spec, multi_spec[, split_on])
   ## sort by order of appearance of split variables in multi_spec
@@ -1027,19 +1099,19 @@ filter_blanks <- function(x) {
 #' @param x A file name.
 #' @return Whether the file is (respectively)
 #'  csv, xlsx, or xls.
-#' @rdname file_checkers
+#' @rdname file-checkers
 #'   
 #' @keywords internal
 is_csv <- function(x) {
   tolower(tools::file_ext(x)) == "csv"
 }
 
-#' @rdname file_checkers
+#' @rdname file-checkers
 is_xlsx <- function(x) {
   tolower(tools::file_ext(x)) == "xlsx"
 }
 
-#' @rdname file_checkers
+#' @rdname file-checkers
 is_xls <- function(x) {
   tolower(tools::file_ext(x)) == "xls"
 }
@@ -1102,12 +1174,13 @@ save_outputs <- function(outputs, output_dir, overwrite) {
     row.names = FALSE
   )
   
-  utils::write.csv(
-    summary(outputs$dsa)$res_comp,
-    file = file.path(output_dir, "dsa.csv"),
-    row.names = FALSE
-  )
-  
+  if(!is.null(outputs$dsa)){
+    utils::write.csv(
+      summary(outputs$dsa)$res_comp,
+      file = file.path(output_dir, "dsa.csv"),
+      row.names = FALSE
+    )
+  }
   
   utils::write.csv(
     outputs$psa$psa,
@@ -1124,19 +1197,20 @@ save_outputs <- function(outputs, output_dir, overwrite) {
   this_file <- "state_count_plot"
   save_graph(this_plot, output_dir, this_file)
   
-  this_plot <- plot(outputs$dsa)
-  this_file <- "dsa"
-  save_graph(this_plot, output_dir, this_file)
-  
+  if(!is.null(outputs$dsa)){
+    this_plot <- plot(outputs$dsa)
+    this_file <- "dsa"
+    save_graph(this_plot, output_dir, this_file)
+  }
   
   ## plots about differences between models
   if (options()$heemod.verbose) message("** Generating plots with model differences...")
   
-  this_plot <- plot(outputs$dsa, type = "difference")
-  this_file <- "dsa_diff"
-  
-  save_graph(this_plot, output_dir, this_file)
-  
+  if(!is.null(outputs$dsa)){
+    this_plot <- plot(outputs$dsa, type = "difference")
+    this_file <- "dsa_diff"
+    save_graph(this_plot, output_dir, this_file)
+  }
   if(!is.null(outputs$psa)){
     this_plot <- plot(outputs$psa)
     this_file <- paste("psa")
@@ -1234,7 +1308,8 @@ modify_param_defs_for_multinomials <- function(param_defs, psa) {
     function(x) {
       zz <- data.frame(
         parameter = names(x),
-        value = x)
+        value = x,
+        stringsAsFactors = FALSE)
       rownames(zz) <- NULL
       zz
     })
@@ -1254,7 +1329,7 @@ modify_param_defs_for_multinomials <- function(param_defs, psa) {
         (this_pos + 1):nrow(param_defs)
       }
     
-    param_defs <- rbind(
+    param_defs <- dplyr::bind_rows(
       param_defs[start_index,],
       replacements[[i]],
       param_defs[end_index,])
@@ -1264,166 +1339,111 @@ modify_param_defs_for_multinomials <- function(param_defs, psa) {
 }
 
 
-#' construct a survival object from tabular specification
-#'
-#' @param surv_def a data frame with the specification.  See details.
-#' @param fit_tibble the name of the tibble from which to take fits.
-#   Typically produced by [survival_fits_from_tabular()].
-#' @param env an environment
-#' @param state_names names of the model states
-#' @details  This function is meant to be used only from within
-#'   tabular_input.R.   It won't work well otherwise, in that
-#'   the environment is unlikely to have what you need.
-#' 
-#' columns of surv_def:  .strategy, .type, .subset, dist, until
-#'   where dist can be either the name of a distribution
-#'   along with parameters, or a reference to a fit
-#'   for example:  fit('exp') or exp(rate = 0.5)
-
-#' @return a list with one element for each strategy.   Each element
-#'   is in turn a `part_surv` object, a list with two elements, 
-#'   pfs and os.   And those
-#'   elements are survival objects of various kinds, with the
-#'   commonality that they can be used in [compute_surv()].
-#'
-
-construct_part_surv_tib <- function(surv_def, fit_tibble,
-                                    state_names,
-                                    env = new.env()) {
-  
-  surv_def_names <- c(".strategy", ".type", "dist")
-  fit_tibble_names <- c("treatment", "type", "dist", "set_name", "fit")
-  if (!all(present_names <- surv_def_names %in% names(surv_def))) {
-    stop("missing required names in 'surv_def': ",
-         paste(surv_def_names[!present_names], collapse = ", "))
-  }
-  if (!all(present_names <- fit_tibble_names %in% names(fit_tibble))) {
-    stop("missing required names in 'fit_tibble': ",
-         paste(fit_tibble_names[!present_names], collapse = ", "))
-  }
-  
-  if (!(".subset" %in% names(surv_def))) {
-    surv_def$.subset <- "all"
-    message("no '.subset' column; defaulting to subset 'all'")
-  }
-  surv_def <- tibble::as_tibble(surv_def)
-  fit_tibble <- dplyr::mutate_(fit_tibble, type = ~ toupper(type)) 
-  
-  ## we handle directly defined distributions
-  ##   (those defined with define_survival())
-  ##   separately from fits
-  with_direct_dist <- dplyr::filter_(
-    surv_def, ~ grepl("^define_survival", dist))
-  should_be_fits <- dplyr::filter_(
-    surv_def, ~ !grepl("^define_survival", dist))
-  
-  ## reduce fit expressions to distribution names
-  should_be_fits_2 <- should_be_fits %>% 
-    dplyr::mutate_(
-      dist = ~ gsub("fit\\((.*)\\)", "\\1", dist) %>% 
-        gsub("'", "", .) %>% 
-        gsub('"', '', .),
-      .type = ~ toupper(.type))
-  ## and join in the fits and subset definitions
-  should_be_fits_3 <- should_be_fits_2 %>%
-    dplyr::left_join(
-      fit_tibble,
-      by = c(".strategy" = "treatment",
-             ".type" = "type",
-             "dist" = "dist",
-             ".subset" = "set_name")
-    )
-  if (any(problem <- sapply(should_be_fits_3$fit, is.na))) {
-    print(surv_def[problem,])
-    stop("fit not found for lines ",
-         paste(which(problem), collapse = ", "),
-         "(shown above)")
-  }
-  ## for directly defined distributions, join to make the
-  ##   extra columns, then move the defined distributions 
-  ##   over to the fits column
-  direct_dist_def_3 <- with_direct_dist %>%
-    dplyr::left_join(
-      fit_tibble,
-      by = c(".strategy" = "treatment",
-             ".type" = "type",
-             "dist" = "dist",
-             ".subset" = "set_name")
-    )
-  direct_dist_def_3$fit <- direct_dist_def_3$dist
-  
-  ## and now we can rejoin them and continue
-  surv_def_4 <- rbind(
-    should_be_fits_3,
-    direct_dist_def_3) %>% 
-    dplyr::group_by_(~ .strategy, ~ .type, ~ .subset) %>%
-    dplyr::do_(fit = ~ join_fits_across_time(.)) %>%
-    dplyr::ungroup()
-  surv_def_5 <- surv_def_4 %>%
-    dplyr::group_by_(~ .strategy, ~ .subset) %>%
-    dplyr::rename_(type = ~ .type) %>%
-    dplyr::do_(
-      part_surv = ~ make_part_surv_from_small_tibble(
-        ., state_names = state_names))
-  surv_def_5
-}
-
-join_fits_across_time <- function(this_part) {
-  if ("until" %in% names(this_part)) {
-    this_part <- dplyr::arrange_(this_part, ~ until)
-    
-    join_(dots = this_part$fit, 
-             at= this_part$until[!is.na(this_part$until)])
-    
-  } else {
-    if (nrow(this_part) > 1) {
-      print(this_part)
-      stop(
-        "can't have more than one distribution for a single ",
-        "strategy and type unless 'until' is also specified"
-      )
+## make sure that survival fit specifications are 
+##   properly formatted and have reasonable data
+check_survival_specs <- 
+  function(surv_specs){
+    ## if there are troubles with absolute file paths, 
+    ##   might want to add an "absolute" column to surv_specs
+    ##   to be explicit (if, possibly, a little redundant)
+    if(!is.data.frame(surv_specs) || nrow(surv_specs) == 0)
+      stop("surv_specs must be a data frame with at least one row")
+    if(!("event_code" %in% names(surv_specs))){
+      warning("event_code not defined in surv_specs; setting to 1 for all rows")
+      surv_specs$event_code <- 1
     }
-    this_part$fit[[1]]
+    if(!("censor_code" %in% names(surv_specs))){
+      warning("censor_code not defined in surv_specs; setting to 0 for all rows")
+      surv_specs$censor_code <- 0
+    }
+      
+    surv_spec_col_names <- c("type", "treatment", "data_directory", "data_file",
+                             "fit_directory", "fit_name", "fit_file",
+                             "time_col", "treatment_col", "censor_col",
+                             "event_code", "censor_code"
+                             )
+    if(! identical(sort(names(surv_specs)), sort(surv_spec_col_names))){
+      extra_names <- setdiff(names(surv_specs), surv_spec_col_names)
+      missing_names <- setdiff(surv_spec_col_names, names(surv_specs))
+      names_message <- paste("surv_ref must have column names:\n",
+                             paste(surv_spec_col_names, collapse = ", "), 
+                             sep = "")
+      if(length(extra_names) > 0)
+        names_message <- paste(names_message, "\n", "extra names: ",
+                               paste(extra_names, collapse = ", "),
+                               sep = "")
+      if(length(missing_names) > 0)
+        names_message <- paste(names_message, "\n", "missing names: ",
+                               paste(missing_names, collapse = ", "),
+                               sep = "")
+      stop(names_message)
+    }
+    
+    if(any(is.na(surv_specs) | surv_specs == ""))
+      stop("all elements of surv_specs must be filled in")
+    
+    ## sort survival specs by treatment, then PFS and OS
+    ## our checks will make sure that we have the right entries,
+    ##   and that they are in the right order
+    surv_specs <- 
+      surv_specs %>% dplyr::arrange_(~ treatment, ~ desc(type))
+    
+    os_ind <- grep("os", surv_specs$type, ignore.case = TRUE)
+    pfs_ind <- grep("pfs", surv_specs$type, ignore.case = TRUE)
+    all_even_os <- identical(as.numeric(os_ind), 
+                             seq(from = 2, 
+                                 to = nrow(surv_specs),
+                                 by = 2))
+    all_odd_pfs <- identical(as.numeric(pfs_ind), 
+                             seq(from = 1, 
+                                 to = nrow(surv_specs),
+                                 by = 2))
+    same_treatments <- 
+      identical(surv_specs$treatment[os_ind],
+                surv_specs$treatment[pfs_ind])
+    if(!all_even_os | !all_odd_pfs | !same_treatments)
+      stop("each treatment must have exactly one PFS and one OS entry")
+    
+    if(any(dups <- duplicated(surv_specs[, c("type", "treatment")]))){
+      print(surv_specs[dups,])
+      stop("survival fit specification can only have one row for fitting ",
+           "OS or PFS for a given treatment\n")
+    }
+    if(any(dups <- duplicated(surv_specs[, c("fit_directory", "fit_file", 
+                                             "time_col", "censor_col")]))){
+      print(surv_specs[dups,])
+      stop("can only specify a given data file in a given directory with ",
+           "the same time column and censoring column for one fit")
+    }
+    surv_specs
   }
-}
 
-make_part_surv_from_small_tibble <- function(st, state_names) {
-  pfs_row <- grep("pfs", st$type, ignore.case = TRUE)
-  os_row <- grep("os", st$type, ignore.case = TRUE)
-  stopifnot(
-    length(pfs_row) == 1,
-    length(os_row) == 1
-  )
-  define_part_surv(pfs = st[[pfs_row, "fit"]],
-                   os = st[[os_row, "fit"]],
-                   state_names = state_names)
-}
-
-#' Convert saved fits to partitioned survival objects
-#' 
-#' @param surv_inputs a list of matrices of `flexsurvreg`
-#'   objects, for example the first element of the output of
-#'   `survival_from_data`.
-#' @param state_names names of states of the model
-#'   
-#' @details  surv_inputs is a tibble with columns type (PFS
-#'   or OS, not case sensitive), treatment, set_name (for
-#'   data subsets), dist (for survival distribution
-#'   assumptions), fit (for the fitted survival object) and
-#'   set_def (how the subset of data was defined, just to
-#'   keep it around)
-
-#' @return a tibble of partitioned survival objects, similar to the
-#'   original tibble of survival fits, with all the columns
-#'   except type and fit, and a new column part_surv.
+#' Load a set of survival fits
+#'
+#' @param location base directory
+#' @param survival_specs information about fits
+#' @param use_envir an environment
+#'
+#' @return A list with two elements:  \itemize{
+#'    \item{`best_models`, 
+#'    a list with the fits for each data file passed in; and} 
+#'    \item{`envir`, 
+#'    an environment containing the models so they can be referenced to 
+#'    get probabilities.}
+#'    }
 #' @export
 #'
-part_survs_from_surv_inputs <- function(surv_inputs, state_names) {
-  
-  surv_inputs %>%
-    dplyr::group_by_(
-      ~ treatment, ~ set_name, ~ dist, ~ set_def) %>%
-    dplyr::do_(
-      part_surv = ~ make_part_surv_from_small_tibble(
-        ., state_names = state_names))
+load_surv_models <- function(location, survival_specs, use_envir){
+  fit_files <- file.path(location,
+                         survival_specs$fit_directory,
+                         survival_specs$fit_file)
+  for(index in seq(along = fit_files)){
+    this_fit_file <- fit_files[index]
+    this_fit_name <- survival_specs$fit_name[index]
+    load(paste(this_fit_file, ".RData", sep = ""))
+  }
+  surv_models <- mget(survival_specs$fit_name)
+  names(surv_models) <- survival_specs$fit_name
+  list(do.call("rbind", mget(survival_specs$fit_name)),
+       env = use_envir)
 }
